.. :changelog:

History
-------

0.2.0 (2017-02-12)
++++++++++++++++++

* Now we have a `BaseFineUploader`
* A basic planing for Beta release: https://github.com/douglasmiranda/django-fine-uploader/projects/1
* Better info on README and more

0.1.0 (2017-02-10)
++++++++++++++++++

* First release on PyPI.
